@@ -1,4 +1,6 @@
 #include "homcloud_common.h"
+#include "homcloud_cgal.h"
+#include "homcloud_numpy.h"
 #include "alpha_shape_common.h"
 
 #include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
@@ -11,7 +13,6 @@
 #include <CGAL/Triangulation_vertex_base_with_info_3.h>
 #include <CGAL/Alpha_shape_cell_base_3.h>
 #include <CGAL/Alpha_shape_vertex_base_3.h>
-#include <CGAL/Robust_weighted_circumcenter_filtered_traits_3.h>
 
 #include <fstream>
 
@@ -223,10 +224,6 @@ static int AlphaShape3_init(AlphaShape3* self,
   return 0;
 }
 
-static PyObject* AlphaShape3_num_vertices(AlphaShape3* self) {
-  return Py_BuildValue("i", self->alpha_shape_->number_of_vertices());
-}
-
 // Return all finite vertices
 static PyObject* AlphaShape3_vertices(AlphaShape3* self) {
   return AlphaShape_tolist<AlphaShape3_Types, Vertex>
@@ -377,9 +374,6 @@ error:
 }
 
 static PyMethodDef AlphaShape3_methods[] = {
-  {"num_vertices",
-   (PyCFunction)AlphaShape3_num_vertices, METH_NOARGS,
-   "Return the number of vertices"},
   {"vertices",
    (PyCFunction)AlphaShape3_vertices, METH_NOARGS,
    "Return vertices"},
@@ -447,6 +441,7 @@ static PyMethodDef Vertex_methods[] = {
    "Return the coordinate of the vertex"},
   {"weight", (PyCFunction)Vertex_weight, METH_NOARGS,
    "Return the weight of the vertex"},
+  {"isvertex", (PyCFunction)method_return_true, METH_NOARGS, "Return True"},
   {NULL}
 };
 
@@ -498,6 +493,7 @@ static PyMethodDef Cell_methods[] = {
   {"vertices",
    (PyCFunction)Cell_vertices, METH_NOARGS,
    "Return vertices of the cell"},
+  {"isvertex", (PyCFunction)method_return_false, METH_NOARGS, "Return False"},
   {NULL}
 };
   
@@ -543,6 +539,7 @@ static PyTypeObject CellType = {
 static PyMethodDef Edge_methods[] = {
   {"vertices", (PyCFunction)Edge_vertices, METH_NOARGS,
    "Return endpoint vertices of the edge"},
+  {"isvertex", (PyCFunction)method_return_false, METH_NOARGS, "Return False"},
   {NULL}
 };
   
@@ -588,6 +585,7 @@ static PyTypeObject EdgeType = {
 static PyMethodDef Facet_methods[] = {
   {"vertices", (PyCFunction)Facet_vertices, METH_NOARGS,
    "Return endpoint vertices of the edge"},
+  {"isvertex", (PyCFunction)method_return_false, METH_NOARGS, "Return False"},
   {NULL}
 };
   
