@@ -1,5 +1,5 @@
-#ifndef HOMCLOUD_ALPHA_SHAPE_COMMON
-#define HOMCLOUD_ALPHA_SHAPE_COMMON
+#ifndef HOMCLOUD_ALPHA_SHAPE_COMMON_H
+#define HOMCLOUD_ALPHA_SHAPE_COMMON_H
 
 // Some common functions for alpha_shape_3 and alpha_shape_2
 static bool ArrayHasCorrectShape(PyArrayObject* points, int dim, int weighted,
@@ -37,4 +37,12 @@ error:
   return NULL;
 }
 
-#endif // HOMCLOUD_ALPHA_SHAPE_COMMON
+static PyObject* method_return_true(PyObject* self) {
+  Py_RETURN_TRUE;
+}
+
+static PyObject* method_return_false(PyObject* self) {
+  Py_RETURN_FALSE;
+}
+
+#endif // HOMCLOUD_ALPHA_SHAPE_COMMON_H
