@@ -3,7 +3,7 @@ import homcloud.paraview_interface as pv_interface
 
 
 class BitmapOptimal1Cycle(object):
-    """The class represents an optimal (not volume-optimal) 1-cycle.
+    """The class represents an optimal (not volume-optimal) 1-cycle for bitmap.
 
     Computing volume-optimal cycle is very expensive for 3-D and
     higher dimensional cubical filtration. To fight against such
@@ -94,6 +94,7 @@ class BitmapOptimal1Cycle(object):
             cycle.orig.draw(drawer, i, str(i))
         f = pv_interface.TempFile(".vtk")
         drawer.write(f)
+        f.close()
         return pv_interface.VTK(f.name, gui_name, f).set_representation("Wireframe")
 
     to_pvnode = to_paraview_node
