@@ -24,6 +24,7 @@ import homcloud.pdgm as pdgm
 import homcloud.pdgm_format as pdgm_format
 import homcloud.diagram as homdiag
 import homcloud.pict.optimal_one_cycle as pict_opt1cyc
+import homcloud.optimal_one_cycle as opt1cyc
 import homcloud.plot_PD_slice as plot_PD_slice
 from homcloud.spatial_searcher import SpatialSearcher
 
@@ -32,6 +33,7 @@ from .histogram import HistoSpec, SliceHistogram
 from .optimal_volume import OptimalVolume, StableVolume
 from .exceptions import VolumeNotFound
 from .bitmap_optimal_1_cycle import BitmapOptimal1Cycle
+from .boundary_map_optimal_1_cycle import Optimal1Cycle
 from .ph0_component import PH0Components
 
 
@@ -794,10 +796,6 @@ class PD(object):
                     self.filtration_type
                 )))
 
-    @cached_property
-    def optimal_1_cycle_finder(self):
-        return pict_opt1cyc.Finder(self.pd)
-
 
 class Pair(object):
     """
@@ -963,10 +961,19 @@ class Pair(object):
                 or the degree of the pair is not 1.
         """
         assert self.degree == 1
-        result = self.diagram.optimal_1_cycle_finder.query_pair(
-            self.birth_index, self.death_index
-        )
-        return BitmapOptimal1Cycle(result)
+        if self.diagram.filtration_type == "bitmap":
+            return self.bitmap_optimal_1_cycle()
+        else:
+            return self.boundary_map_optimal_1_cycle()
+        
+    def bitmap_optimal_1_cycle(self):
+        finder = pict_opt1cyc.Finder(self.diagram.pd)
+        return BitmapOptimal1Cycle(finder.query_pair(self.birth_index, self.death_index))
+
+    def boundary_map_optimal_1_cycle(self):
+        return Optimal1Cycle(self, opt1cyc.search_on_chunk_bytes(
+            self.diagram.pd.boundary_map_bytes, self.birth_index
+        ))
 
     def __eq__(self, other):
         return (isinstance(other, Pair) and
