@@ -125,6 +125,10 @@ class PDGM(object):
     def load_boundary_map(self):
         return self.boundary_map_chunk
 
+    @property
+    def boundary_map_bytes(self):
+        return self.pdgmreader.load_chunk_bytes("boundary_map")
+
     def default_vertex_symbols(self):
         return [str(k) for k in range(self.num_vertices)]
 
