@@ -1,5 +1,6 @@
 import sys
 from argparse import ArgumentParser
+import base64
 
 import numpy as np
 
@@ -58,26 +59,40 @@ def write_vtk_file(f, path, pict):
         f.write("%f\n" % value)
 
 
-def write_vti_xmlfile(f, pict):
-    zw, yw, xw = pict.shape
+def extend_2d_3d(array, default_value):
+    if len(array) == 2:
+        return default_value, array[0], array[1]
+    else:
+        return array
+
+
+def write_vti_xmlfile(f, pict, offsets=[0.0, 0.0, 0.0]):
+    zw, yw, xw = extend_2d_3d(pict.shape, 1)
+    offsets = extend_2d_3d(offsets, 0.0)
+
     header = """<?xml version="1.0"?>
-    <VTKFile type="ImageData">
+    <VTKFile type="ImageData" byte_order="LittleEndian" header_type="UInt64">
       <ImageData WholeExtent="0 {0} 0 {1} 0 {2}" 
-                 Origin="-0.5 -0.5 -0.5" 
+                 Origin="{3} {4} {5}" 
                  Spacing="1.0 1.0 1.0">
         <Piece Extent="0 {0} 0 {1} 0 {2}">
           <CellData Scalars="value">
-            <DataArray Name="value" type="Float64" format="ascii">
-    """.format(xw, yw, zw)
-    footer = """
+            <DataArray Name="value" type="Float64" format="appended" offset="0">
             </DataArray>
           </CellData>
         </Piece>
       </ImageData>
+      <AppendedData encoding="base64">
+    """.format(xw, yw, zw, offsets[2] - 0.5, offsets[1] - 0.5, offsets[0] - 0.5)
+
+    footer = """
+      </AppendedData>
     </VTKFile>
     """
+
     f.write(header)
-    np.savetxt(f, pict.ravel())
+    f.write("_")
+    f.write(base64.b64encode(pict.astype(np.float64).tobytes(order="C")).decode("ascii"))
     f.write(footer)
 
 
