@@ -273,6 +273,48 @@ class ParaViewCubeDrawer(ParaViewDrawer):
         f.write("\n")
 
 
+class ParaViewSparseCubeDrawer(ParaViewDrawer):
+    def __init__(self, n_colors, ndim, column_names):
+        super().__init__(n_colors, column_names)
+        self.ndim = ndim
+        self.points = []
+        assert ndim in [2, 3]
+
+    def draw_cube(self, coord, non_deg, color, **threshold_values):
+        indices, dvs = self.prepare_points(coord, non_deg)
+        for dv in dvs:
+            for dl in ParaViewCubeDrawer.dls(non_deg):
+                if np.max(dv + dl) < 2:
+                    self.draw_line(indices[tuple(dv)], indices[tuple(dv + dl)], color,
+                                   **threshold_values)
+
+    def draw_cell(self, cell, cube_geom_resolver, color, **threshold_values):
+        coord, non_deg = cube_geom_resolver.resolve_cell(cell)
+        self.draw_cube(coord, non_deg, color, **threshold_values)
+
+    def prepare_points(self, coord, non_deg):
+        dvs = ParaViewCubeDrawer.dvs(non_deg)
+        indices = np.zeros([2] * self.ndim, dtype=int)
+        for dv in dvs:
+            indices[tuple(dv)] = len(self.points)
+            self.points.append(np.flip(dv + coord))
+        return indices, dvs
+
+    def output_points(self, f):
+        f.write("POINTS {} double\n".format(self.num_points()))
+        for point in self.points:
+            f.write("{} {} {}\n".format(point[0], point[1], point[2]))
+        f.write("\n")
+
+    def num_points(self):
+        return len(self.points)
+
+    def output_lines(self, f):
+        f.write("LINES {} {}\n".format(self.num_lines(), self.num_lines() * 3))
+        for line in self.lines:
+            f.write("2 {} {}\n".format(line[0], line[1]))
+        f.write("\n")
+
 class ParaViewSparseBitmapDrawer(ParaViewDrawer):
     def __init__(self, n_colors, column_names):
         super().__init__(n_colors, column_names)
